@@ -1,27 +1,32 @@
-## ---- echo = FALSE, message = FALSE, warning = FALSE--------------------------
-library(ParallelLogger)
+## ---- eval=FALSE--------------------------------------------------------------
+#  logger <- createLogger(name = "SIMPLE",
+#                         threshold = "INFO",
+#                         appenders = list(createConsoleAppender(layout = layoutTimestamp)))
+#  
+#  registerLogger(logger)
+#  
+#  logTrace("This event is below the threshold (INFO)")
+#  
+#  logInfo("Hello world")
 
-## -----------------------------------------------------------------------------
-logger <- createLogger(name = "SIMPLE",
-                       threshold = "INFO",
-                       appenders = list(createConsoleAppender(layout = layoutTimestamp)))
+## ---- echo=FALSE--------------------------------------------------------------
+out <- "Hello world
+2021-02-23 09:04:06 Hello world"
+writeLines(out)
 
-registerLogger(logger)
+## ---- eval=FALSE--------------------------------------------------------------
+#  clearLoggers()
+#  
+#  logger <- createLogger(name = "SIMPLE",
+#                         threshold = "INFO",
+#                         appenders = list(createConsoleAppender(layout = layoutTimestamp)))
+#  
+#  registerLogger(logger)
+#  
+#  logInfo("Hello world")
 
-logTrace("This event is below the threshold (INFO)")
-
-logInfo("Hello world")
-
-## -----------------------------------------------------------------------------
-clearLoggers()
-
-logger <- createLogger(name = "SIMPLE",
-                       threshold = "INFO",
-                       appenders = list(createConsoleAppender(layout = layoutTimestamp)))
-
-registerLogger(logger)
-
-logInfo("Hello world")
+## ---- echo=FALSE--------------------------------------------------------------
+writeLines("2021-02-23 09:04:06 Hello world")
 
 ## ---- eval=FALSE--------------------------------------------------------------
 #  addDefaultConsoleLogger()
@@ -31,30 +36,35 @@ logInfo("Hello world")
 #                              threshold = "INFO",
 #                              appenders = list(createConsoleAppender(layout = layoutSimple))))
 
-## ---- echo = FALSE, message = FALSE, warning = FALSE--------------------------
-logFileName <- tempfile()
-
 ## ---- eval=FALSE--------------------------------------------------------------
 #  logFileName <- "log.txt"
+#  
+#  logger <- createLogger(name = "PARALLEL",
+#                         threshold = "TRACE",
+#                         appenders = list(createFileAppender(layout = layoutParallel,
+#                                                             fileName = logFileName)))
+#  registerLogger(logger)
+#  
+#  logTrace("Executed this line")
+#  
+#  logDebug("There are ",  length(getLoggers()), " loggers")
+#  
+#  logInfo("Hello world")
 
-## -----------------------------------------------------------------------------
-logger <- createLogger(name = "PARALLEL",
-                       threshold = "TRACE",
-                       appenders = list(createFileAppender(layout = layoutParallel,
-                                                           fileName = logFileName)))
-registerLogger(logger)
+## ---- echo=FALSE--------------------------------------------------------------
+writeLines("2021-02-23 09:04:06 Hello world")
 
-logTrace("Executed this line")
+## ---- eval=FALSE--------------------------------------------------------------
+#  writeLines(readChar(logFileName, file.info(logFileName)$size))
 
-logDebug("There are ",  length(getLoggers()), " loggers")
+## ----echo=FALSE---------------------------------------------------------------
+out <- "2021-02-23 09:04:06\t[Main thread]\tTRACE\tevaluate\ttiming_fn\tExecuted this line
+2021-02-23 09:04:06\t[Main thread]\tDEBUG\tevaluate\ttiming_fn\tThere are 2 loggers
+2021-02-23 09:04:06\t[Main thread]\tINFO\tevaluate\ttiming_fn\tHello world"
+writeLines(out)
 
-logInfo("Hello world")
-
-## -----------------------------------------------------------------------------
-writeLines(readChar(logFileName, file.info(logFileName)$size))
-
-## -----------------------------------------------------------------------------
-unlink(logFileName)
+## ---- eval=FALSE--------------------------------------------------------------
+#  unlink(logFileName)
 
 ## ---- eval=FALSE--------------------------------------------------------------
 #  addDefaultFileLogger(logFileName)
@@ -120,36 +130,52 @@ unlink(logFileName)
 #  
 #  writeLines(readChar(logFileName, file.info(logFileName)$size))
 
-## ---- echo = FALSE, message = FALSE, warning = FALSE--------------------------
-# knitr seems to use the same hook to capture warnings and errors, so minor cheat here:
-clearLoggers()
-addDefaultFileLogger(logFileName)
-logWarn("Danger!")
-logWarn("Warning: NAs introduced by coercion")
-logFatal("Error: object a not found")
-writeLines(readChar(logFileName, file.info(logFileName)$size))
+## ----echo=FALSE---------------------------------------------------------------
+out <- "2021-02-23 09:04:09\t[Main thread]\tWARN\tevaluate\ttiming_fn\tDanger!
+2021-02-23 09:04:09\t[Main thread]\tWARN\tevaluate\ttiming_fn\tWarning: NAs introduced by coercion
+2021-02-23 09:04:09\t[Main thread]\tFATAL\tevaluate\ttiming_fn\tError: object a not found"
+writeLines(out)
 
-## -----------------------------------------------------------------------------
-unlink(logFileName) # Clean up log file from the previous example
-clearLoggers() # Clean up the loggers from the previous example
+## ---- eval=FALSE--------------------------------------------------------------
+#  clearLoggers() # Clean up the loggers from the previous example
+#  
+#  addDefaultFileLogger(logFileName)
+#  
+#  cluster <- makeCluster(3)
+#  
+#  fun <- function(x) {
+#    ParallelLogger::logInfo("The value of x is ", x)
+#    # Do something
+#    if (x == 6)
+#      ParallelLogger::logDebug("X equals 6")
+#    return(NULL)
+#  }
+#  
+#  dummy <- clusterApply(cluster, 1:10, fun, progressBar = FALSE)
+#  
+#  stopCluster(cluster)
+#  
+#  writeLines(readChar(logFileName, file.info(logFileName)$size))
 
-addDefaultFileLogger(logFileName)
-
-cluster <- makeCluster(3)
-
-fun <- function(x) {
-  ParallelLogger::logInfo("The value of x is ", x)
-  # Do something
-  if (x == 6)
-    ParallelLogger::logDebug("X equals 6")
-  return(NULL)
-}
-
-dummy <- clusterApply(cluster, 1:10, fun, progressBar = FALSE)
-
-stopCluster(cluster)
-
-writeLines(readChar(logFileName, file.info(logFileName)$size))
+## ----echo=FALSE---------------------------------------------------------------
+out <- "2021-02-23 09:04:09\t[Main thread]\tTRACE\tevaluate timing_fn Initiating cluster with 3 threads
+2021-02-23 09:04:13\t[Thread 1]\tTRACE\t\tThread 1 initiated
+2021-02-23 09:04:13\t[Thread 2]\tTRACE\t\tThread 2 initiated
+2021-02-23 09:04:13\t[Thread 3]\tTRACE\t\tThread 3 initiated
+2021-02-23 09:04:13\t[Thread 1]\tINFO\t\tThe value of x is 1
+2021-02-23 09:04:13\t[Thread 2]\tINFO\t\tThe value of x is 2
+2021-02-23 09:04:13\t[Thread 1]\tINFO\t\tThe value of x is 4
+2021-02-23 09:04:13\t[Thread 2]\tINFO\t\tThe value of x is 5
+2021-02-23 09:04:13\t[Thread 3]\tINFO\t\tThe value of x is 6
+2021-02-23 09:04:13\t[Thread 1]\tINFO\t\tThe value of x is 7
+2021-02-23 09:04:13\t[Thread 2]\tINFO\t\tThe value of x is 8
+2021-02-23 09:04:13\t[Thread 1]\tINFO\t\tThe value of x is 9
+2021-02-23 09:04:13\t[Thread 2]\tINFO\t\tThe value of x is 10
+2021-02-23 09:04:13\t[Main thread]\tTRACE\tevaluate\ttiming_fn Stopping cluster
+2021-02-23 09:04:13\t[Thread 1]\tTRACE\t\tThread 1 terminated
+2021-02-23 09:04:13\t[Thread 3]\tTRACE\t\tThread 3 terminated
+2021-02-23 09:04:13\t[Thread 2]\tTRACE\t\tThread 2 terminated"
+writeLines(out)
 
 ## ---- eval=FALSE--------------------------------------------------------------
 #  subSubTask <- function() {
@@ -195,6 +221,3 @@ writeLines(readChar(logFileName, file.info(logFileName)$size))
 ## ---- eval=FALSE--------------------------------------------------------------
 #  launchLogViewer(logFileName)
 
-## ---- echo = FALSE, message = FALSE, warning = FALSE--------------------------
-unlink(logFileName)
-
